@@ -55,25 +55,25 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_ecs
-import aws_cdk.aws_rds
-import aws_cdk.core
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_67de8e8d
+import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_7896c08f
+import aws_cdk.aws_rds as _aws_cdk_aws_rds_9543e6d5
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
 class WordPress(
-    aws_cdk.core.Construct,
+    _aws_cdk_core_f4b25747.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-wordpress.WordPress",
 ):
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: _aws_cdk_core_f4b25747.Construct,
         id: builtins.str,
         *,
-        cluster: typing.Optional[aws_cdk.aws_ecs.Cluster] = None,
-        rds_instance: typing.Optional[aws_cdk.aws_rds.DatabaseInstance] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        cluster: typing.Optional[_aws_cdk_aws_ecs_7896c08f.Cluster] = None,
+        rds_instance: typing.Optional[_aws_cdk_aws_rds_9543e6d5.DatabaseInstance] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
     ) -> None:
         '''
         :param scope: -
@@ -83,16 +83,7 @@ class WordPress(
         :param vpc: The WordPress VPC.
         '''
         if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                cluster: typing.Optional[aws_cdk.aws_ecs.Cluster] = None,
-                rds_instance: typing.Optional[aws_cdk.aws_rds.DatabaseInstance] = None,
-                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__db7cc402012ef89de5a356e24d3136be850bd259f7c51b04db67faad69c2a8f9)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = WordPressProps(cluster=cluster, rds_instance=rds_instance, vpc=vpc)
@@ -114,9 +105,9 @@ class WordPressProps:
     def __init__(
         self,
         *,
-        cluster: typing.Optional[aws_cdk.aws_ecs.Cluster] = None,
-        rds_instance: typing.Optional[aws_cdk.aws_rds.DatabaseInstance] = None,
-        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        cluster: typing.Optional[_aws_cdk_aws_ecs_7896c08f.Cluster] = None,
+        rds_instance: typing.Optional[_aws_cdk_aws_rds_9543e6d5.DatabaseInstance] = None,
+        vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
     ) -> None:
         '''The interface for all wordpress.
 
@@ -125,18 +116,11 @@ class WordPressProps:
         :param vpc: The WordPress VPC.
         '''
         if __debug__:
-            def stub(
-                *,
-                cluster: typing.Optional[aws_cdk.aws_ecs.Cluster] = None,
-                rds_instance: typing.Optional[aws_cdk.aws_rds.DatabaseInstance] = None,
-                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__90a36a6d5e121b2c4302e35a3331fcaea9704cc1646448e94ff2271cf03a5d49)
             check_type(argname="argument cluster", value=cluster, expected_type=type_hints["cluster"])
             check_type(argname="argument rds_instance", value=rds_instance, expected_type=type_hints["rds_instance"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if cluster is not None:
             self._values["cluster"] = cluster
         if rds_instance is not None:
@@ -145,22 +129,24 @@ class WordPressProps:
             self._values["vpc"] = vpc
 
     @builtins.property
-    def cluster(self) -> typing.Optional[aws_cdk.aws_ecs.Cluster]:
+    def cluster(self) -> typing.Optional[_aws_cdk_aws_ecs_7896c08f.Cluster]:
         '''The WordPress cluster.'''
         result = self._values.get("cluster")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.Cluster], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_7896c08f.Cluster], result)
 
     @builtins.property
-    def rds_instance(self) -> typing.Optional[aws_cdk.aws_rds.DatabaseInstance]:
+    def rds_instance(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_rds_9543e6d5.DatabaseInstance]:
         '''The WordPress RDS.'''
         result = self._values.get("rds_instance")
-        return typing.cast(typing.Optional[aws_cdk.aws_rds.DatabaseInstance], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_rds_9543e6d5.DatabaseInstance], result)
 
     @builtins.property
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc]:
         '''The WordPress VPC.'''
         result = self._values.get("vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -180,3 +166,23 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__db7cc402012ef89de5a356e24d3136be850bd259f7c51b04db67faad69c2a8f9(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+    *,
+    cluster: typing.Optional[_aws_cdk_aws_ecs_7896c08f.Cluster] = None,
+    rds_instance: typing.Optional[_aws_cdk_aws_rds_9543e6d5.DatabaseInstance] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__90a36a6d5e121b2c4302e35a3331fcaea9704cc1646448e94ff2271cf03a5d49(
+    *,
+    cluster: typing.Optional[_aws_cdk_aws_ecs_7896c08f.Cluster] = None,
+    rds_instance: typing.Optional[_aws_cdk_aws_rds_9543e6d5.DatabaseInstance] = None,
+    vpc: typing.Optional[_aws_cdk_aws_ec2_67de8e8d.IVpc] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
